@@ -74,8 +74,16 @@ class IssueBoundary:
     def _would_cause_double_comma(span: Span) -> bool:
         return (
                 (
-                        span.doc.text[span.start_char - 1] == "," or
-                        (span.doc.text[span.start_char - 1] == " " and span.doc.text[span.start_char - 2] == ",")
+                        (
+                                span.start_char > 0
+                                and span.doc.text[span.start_char - 1] == ","
+                        )
+                        or
+                        (
+                                span.start_char > 1
+                                and span.doc.text[span.start_char - 1] == " "
+                                and span.doc.text[span.start_char - 2] == ","
+                        )
                 )
                 and span.doc.text[span.end_char] == ","
                 and len(span._.suggestions) > 0
